diff --git a/qt/python/CMakeLists.txt b/qt/python/CMakeLists.txt
index f05b391a7bef321d956540ff68dabbc69e4b6748..849f06e7ad59e0564ec7ca86197b585f4c5d28cb 100644
--- a/qt/python/CMakeLists.txt
+++ b/qt/python/CMakeLists.txt
@@ -48,7 +48,7 @@ set ( SIP_HDRS
   ../widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/GroupRowsCommand.h
   ../widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/ImportTableCommand.h
   ../widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/NewTableCommand.h
-  ../widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorOpenTableCommand.h
+  ../widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/OpenTableCommand.h
   ../widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorOptionsCommand.h
   ../widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorPasteSelectedCommand.h
   ../widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorPlotGroupCommand.h
diff --git a/qt/python/mantidqt.sip b/qt/python/mantidqt.sip
index 7ac1606d4deded7bc83218820bd8889108ffb6c9..fd08a16ac503c3bf4246f1968828b631600417ee 100644
--- a/qt/python/mantidqt.sip
+++ b/qt/python/mantidqt.sip
@@ -1809,13 +1809,13 @@ NewTableCommand();
 NewTableCommand(const MantidQt::MantidWidgets::DataProcessor::NewTableCommand &);
 };
 
-class DataProcessorOpenTableCommand
+class OpenTableCommand
 {
 %TypeHeaderCode
-#include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorOpenTableCommand.h"
+#include "MantidQtWidgets/Common/DataProcessorUI/OpenTableCommand.h"
 %End
 public:
-DataProcessorOpenTableCommand(const MantidQt::MantidWidgets::DataProcessor::QDataProcessorWidget &);
+OpenTableCommand(const MantidQt::MantidWidgets::DataProcessor::QDataProcessorWidget &);
 void execute();
 QString name();
 QString icon();
@@ -1824,8 +1824,8 @@ QString whatsthis();
 QString shortcut();
 
 private:
-DataProcessorOpenTableCommand();
-DataProcessorOpenTableCommand(const MantidQt::MantidWidgets::DataProcessor::DataProcessorOpenTableCommand &);
+OpenTableCommand();
+OpenTableCommand(const MantidQt::MantidWidgets::DataProcessor::OpenTableCommand &);
 };
 
 class DataProcessorOptionsCommand
diff --git a/qt/widgets/common/CMakeLists.txt b/qt/widgets/common/CMakeLists.txt
index a89dfcb7314ef51d19297e9332160b1e7a71c064..6378e7f45182faa552401a1f2530b9fd31b008d1 100644
--- a/qt/widgets/common/CMakeLists.txt
+++ b/qt/widgets/common/CMakeLists.txt
@@ -321,7 +321,7 @@ set ( INC_FILES
 	inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorMainPresenter.h
 	inc/MantidQtWidgets/Common/DataProcessorUI/NewTableCommand.h
 	inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorOneLevelTreeManager.h
-	inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorOpenTableCommand.h
+	inc/MantidQtWidgets/Common/DataProcessorUI/OpenTableCommand.h
 	inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorOptionsCommand.h
 	inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorPasteSelectedCommand.h
 	inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorPauseCommand.h
diff --git a/qt/widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorOpenTableCommand.h b/qt/widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/OpenTableCommand.h
similarity index 84%
rename from qt/widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorOpenTableCommand.h
rename to qt/widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/OpenTableCommand.h
index cbfe1898c206702c13c00d42ba02c5977a72e7a1..2113f3cc57314529b8006d200f7493acc28d72b9 100644
--- a/qt/widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/DataProcessorOpenTableCommand.h
+++ b/qt/widgets/common/inc/MantidQtWidgets/Common/DataProcessorUI/OpenTableCommand.h
@@ -6,9 +6,9 @@
 namespace MantidQt {
 namespace MantidWidgets {
 namespace DataProcessor {
-/** @class DataProcessorOpenTableCommand
+/** @class OpenTableCommand
 
-DataProcessorOpenTableCommand defines the action "Open Table"
+OpenTableCommand defines the action "Open Table"
 
 Copyright © 2011-16 ISIS Rutherford Appleton Laboratory, NScD Oak Ridge
 National Laboratory & European Spallation Source
@@ -31,13 +31,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 File change history is stored at: <https://github.com/mantidproject/mantid>.
 Code Documentation is available at: <http://doxygen.mantidproject.org>
 */
-class DataProcessorOpenTableCommand : public CommandBase {
+class OpenTableCommand : public CommandBase {
 public:
-  DataProcessorOpenTableCommand(DataProcessorPresenter *tablePresenter)
+  OpenTableCommand(DataProcessorPresenter *tablePresenter)
       : CommandBase(tablePresenter){};
-  DataProcessorOpenTableCommand(const QDataProcessorWidget &widget)
+  OpenTableCommand(const QDataProcessorWidget &widget)
       : CommandBase(widget){};
-  virtual ~DataProcessorOpenTableCommand(){};
+  virtual ~OpenTableCommand(){};
 
   void execute() override{
       // This action should do nothing
diff --git a/qt/widgets/common/src/DataProcessorUI/DataProcessorOneLevelTreeManager.cpp b/qt/widgets/common/src/DataProcessorUI/DataProcessorOneLevelTreeManager.cpp
index 8f5c053dd157eac1910636f60dd00390c2d6557a..b2a6fc08c988919ca7d0327d448e1361b9370029 100644
--- a/qt/widgets/common/src/DataProcessorUI/DataProcessorOneLevelTreeManager.cpp
+++ b/qt/widgets/common/src/DataProcessorUI/DataProcessorOneLevelTreeManager.cpp
@@ -10,7 +10,7 @@
 #include "MantidQtWidgets/Common/DataProcessorUI/ExportTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/ImportTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/NewTableCommand.h"
-#include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorOpenTableCommand.h"
+#include "MantidQtWidgets/Common/DataProcessorUI/OpenTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorOptionsCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorPasteSelectedCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorPauseCommand.h"
@@ -69,7 +69,7 @@ DataProcessorOneLevelTreeManager::publishCommands() {
 
   std::vector<Command_uptr> commands;
 
-  addCommand(commands, make_unique<DataProcessorOpenTableCommand>(m_presenter));
+  addCommand(commands, make_unique<OpenTableCommand>(m_presenter));
   addCommand(commands, make_unique<NewTableCommand>(m_presenter));
   addCommand(commands, make_unique<DataProcessorSaveTableCommand>(m_presenter));
   addCommand(commands,
diff --git a/qt/widgets/common/src/DataProcessorUI/DataProcessorTwoLevelTreeManager.cpp b/qt/widgets/common/src/DataProcessorUI/DataProcessorTwoLevelTreeManager.cpp
index e5ac42e9e5009b9178ed7c2a6b9aa07116a0bd68..fed7efa20219d43f41f0b17aa482f435d57310f5 100644
--- a/qt/widgets/common/src/DataProcessorUI/DataProcessorTwoLevelTreeManager.cpp
+++ b/qt/widgets/common/src/DataProcessorUI/DataProcessorTwoLevelTreeManager.cpp
@@ -16,7 +16,7 @@
 #include "MantidQtWidgets/Common/DataProcessorUI/ImportTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/NewTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/ExpandGroupsCommand.h"
-#include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorOpenTableCommand.h"
+#include "MantidQtWidgets/Common/DataProcessorUI/OpenTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorOptionsCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorPasteSelectedCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorPauseCommand.h"
@@ -78,7 +78,7 @@ DataProcessorTwoLevelTreeManager::publishCommands() {
 
   std::vector<Command_uptr> commands;
 
-  addCommand(commands, make_unique<DataProcessorOpenTableCommand>(m_presenter));
+  addCommand(commands, make_unique<OpenTableCommand>(m_presenter));
   addCommand(commands, make_unique<NewTableCommand>(m_presenter));
   addCommand(commands, make_unique<DataProcessorSaveTableCommand>(m_presenter));
   addCommand(commands,
diff --git a/qt/widgets/common/test/DataProcessorUI/CommandsTest.h b/qt/widgets/common/test/DataProcessorUI/CommandsTest.h
index 8206a2a574ba4c9832eda598b34722b1dbe68e84..d8a15f4aa96cb5567754c4081d121d60f3f88d8d 100644
--- a/qt/widgets/common/test/DataProcessorUI/CommandsTest.h
+++ b/qt/widgets/common/test/DataProcessorUI/CommandsTest.h
@@ -20,7 +20,7 @@
 #include "MantidQtWidgets/Common/DataProcessorUI/ImportTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorMockObjects.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/NewTableCommand.h"
-#include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorOpenTableCommand.h"
+#include "MantidQtWidgets/Common/DataProcessorUI/OpenTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorOptionsCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorPasteSelectedCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorPauseCommand.h"
@@ -54,7 +54,7 @@ public:
 
   void test_open_table_command() {
     NiceMock<MockDataProcessorPresenter> mockPresenter;
-    DataProcessorOpenTableCommand command(&mockPresenter);
+    OpenTableCommand command(&mockPresenter);
 
     // The presenter should be notified with the OpenTableFlag
     EXPECT_CALL(mockPresenter, notify(DataProcessorPresenter::OpenTableFlag))
diff --git a/qt/widgets/common/test/DataProcessorUI/DataProcessorOneLevelTreeManagerTest.h b/qt/widgets/common/test/DataProcessorUI/DataProcessorOneLevelTreeManagerTest.h
index b60c3c06d553c6af188b6300778e5a2b384aca8b..2ad828edf6925323449606180dedad77420b7fea 100644
--- a/qt/widgets/common/test/DataProcessorUI/DataProcessorOneLevelTreeManagerTest.h
+++ b/qt/widgets/common/test/DataProcessorUI/DataProcessorOneLevelTreeManagerTest.h
@@ -18,7 +18,7 @@
 #include "MantidQtWidgets/Common/DataProcessorUI/ImportTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorMockObjects.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/NewTableCommand.h"
-#include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorOpenTableCommand.h"
+#include "MantidQtWidgets/Common/DataProcessorUI/OpenTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorOptionsCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorPasteSelectedCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorPauseCommand.h"
@@ -127,7 +127,7 @@ public:
     auto comm = manager.publishCommands();
 
     TS_ASSERT_EQUALS(comm.size(), 23);
-    TS_ASSERT(dynamic_cast<DataProcessorOpenTableCommand *>(comm[0].get()));
+    TS_ASSERT(dynamic_cast<OpenTableCommand *>(comm[0].get()));
     TS_ASSERT(dynamic_cast<NewTableCommand *>(comm[1].get()));
     TS_ASSERT(dynamic_cast<DataProcessorSaveTableCommand *>(comm[2].get()));
     TS_ASSERT(dynamic_cast<DataProcessorSaveTableAsCommand *>(comm[3].get()));
diff --git a/qt/widgets/common/test/DataProcessorUI/DataProcessorTwoLevelTreeManagerTest.h b/qt/widgets/common/test/DataProcessorUI/DataProcessorTwoLevelTreeManagerTest.h
index c0b6bd5f323cbdf1ec9557c5aa0efc325bd5854c..79e36ab959f50b42ccd8290b916bf16d15d83236 100644
--- a/qt/widgets/common/test/DataProcessorUI/DataProcessorTwoLevelTreeManagerTest.h
+++ b/qt/widgets/common/test/DataProcessorUI/DataProcessorTwoLevelTreeManagerTest.h
@@ -24,7 +24,7 @@
 #include "MantidQtWidgets/Common/DataProcessorUI/ImportTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorMockObjects.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/NewTableCommand.h"
-#include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorOpenTableCommand.h"
+#include "MantidQtWidgets/Common/DataProcessorUI/OpenTableCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorOptionsCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorPasteSelectedCommand.h"
 #include "MantidQtWidgets/Common/DataProcessorUI/DataProcessorPauseCommand.h"
@@ -139,7 +139,7 @@ public:
     auto comm = manager.publishCommands();
 
     TS_ASSERT_EQUALS(comm.size(), 31);
-    TS_ASSERT(dynamic_cast<DataProcessorOpenTableCommand *>(comm[0].get()));
+    TS_ASSERT(dynamic_cast<OpenTableCommand *>(comm[0].get()));
     TS_ASSERT(dynamic_cast<NewTableCommand *>(comm[1].get()));
     TS_ASSERT(dynamic_cast<DataProcessorSaveTableCommand *>(comm[2].get()));
     TS_ASSERT(dynamic_cast<DataProcessorSaveTableAsCommand *>(comm[3].get()));
diff --git a/scripts/Interface/ui/dataprocessorinterface/data_processor_gui.py b/scripts/Interface/ui/dataprocessorinterface/data_processor_gui.py
index 500df25b44f76babdebab4e4d9e5f587af96b485..d6706fd18e891df7d142220a4507b907985bc3db 100644
--- a/scripts/Interface/ui/dataprocessorinterface/data_processor_gui.py
+++ b/scripts/Interface/ui/dataprocessorinterface/data_processor_gui.py
@@ -175,7 +175,7 @@ class DataProcessorGui(QtGui.QMainWindow, ui_data_processor_window.Ui_DataProces
         self._create_action(MantidQt.MantidWidgets.DeleteGroupCommand(self.data_processor_table), self.menuEdit)
 
         # Actions that go in the 'File' menu
-        self._create_action(MantidQt.MantidWidgets.DataProcessorOpenTableCommand(self.data_processor_table), self.menuFile, workspace_list)
+        self._create_action(MantidQt.MantidWidgets.OpenTableCommand(self.data_processor_table), self.menuFile, workspace_list)
         self._create_action(MantidQt.MantidWidgets.NewTableCommand(self.data_processor_table), self.menuFile)
         self._create_action(MantidQt.MantidWidgets.DataProcessorSaveTableCommand(self.data_processor_table), self.menuFile)
         self._create_action(MantidQt.MantidWidgets.DataProcessorSaveTableAsCommand(self.data_processor_table), self.menuFile)
@@ -186,7 +186,7 @@ class DataProcessorGui(QtGui.QMainWindow, ui_data_processor_window.Ui_DataProces
     def _create_action(self, command, menu, workspace_list = None):
         """
         Create an action from a given Command and add it to a given menu
         A 'workspace_list' can be provided but it is only intended to be used with DataProcessorOpenTableCommand.
         It refers to the list of table workspaces in the ADS that could be loaded into the widget. Note that only
         table workspaces with an appropriate number of columns and column types can be loaded.
         """
@@ -186,7 +186,7 @@ class DataProcessorGui(QtGui.QMainWindow, ui_data_processor_window.Ui_DataProces
         """
         Create an action from a given Command and add it to a given menu
-        A 'workspace_list' can be provided but it is only intended to be used with DataProcessorOpenTableCommand.
+        A 'workspace_list' can be provided but it is only intended to be used with OpenTableCommand.
         It refers to the list of table workspaces in the ADS that could be loaded into the widget. Note that only
         table workspaces with an appropriate number of columns and column types can be loaded.
diff --git a/scripts/Interface/ui/poldi/poldi_gui.py b/scripts/Interface/ui/poldi/poldi_gui.py
index a888d379586b06251057ccc2589caee510a14020..05f37fd7e109ecd45d6dcebf385102a9c211ca44 100644
--- a/scripts/Interface/ui/poldi/poldi_gui.py
+++ b/scripts/Interface/ui/poldi/poldi_gui.py
@@ -164,7 +164,7 @@ class PoldiGui(QtGui.QMainWindow, ui_poldi_window.Ui_PoldiWindow):
         self._create_action(MantidQt.MantidWidgets.DeleteGroupCommand(self.data_processor_table), self.menuEdit)
 
         # Actions that go in the 'File' menu
-        self._create_action(MantidQt.MantidWidgets.DataProcessorOpenTableCommand(self.data_processor_table), self.menuFile, workspace_list)
+        self._create_action(MantidQt.MantidWidgets.OpenTableCommand(self.data_processor_table), self.menuFile, workspace_list)
         self._create_action(MantidQt.MantidWidgets.NewTableCommand(self.data_processor_table), self.menuFile)
         self._create_action(MantidQt.MantidWidgets.DataProcessorSaveTableCommand(self.data_processor_table), self.menuFile)
         self._create_action(MantidQt.MantidWidgets.DataProcessorSaveTableAsCommand(self.data_processor_table), self.menuFile)
@@ -181,7 +181,7 @@ class PoldiGui(QtGui.QMainWindow, ui_poldi_window.Ui_PoldiWindow):
     def _create_action(self, command, menu, workspace_list = None):
         """
         Create an action from a given Command and add it to a given menu
         A 'workspace_list' can be provided but it is only intended to be used with DataProcessorOpenTableCommand.
         It refers to the list of table workspaces in the ADS that could be loaded into the widget. Note that only
         table workspaces with an appropriate number of columns and column types can be loaded.
         """
@@ -181,7 +181,7 @@ class PoldiGui(QtGui.QMainWindow, ui_poldi_window.Ui_PoldiWindow):
         """
         Create an action from a given Command and add it to a given menu
-        A 'workspace_list' can be provided but it is only intended to be used with DataProcessorOpenTableCommand.
+        A 'workspace_list' can be provided but it is only intended to be used with OpenTableCommand.
         It refers to the list of table workspaces in the ADS that could be loaded into the widget. Note that only
         table workspaces with an appropriate number of columns and column types can be loaded.
diff --git a/scripts/Interface/ui/sans_isis/sans_data_processor_gui.py b/scripts/Interface/ui/sans_isis/sans_data_processor_gui.py
index bffefb9eac5faa27a0bde4b175f780edfcf2ab6b..eda1775aa7215e1ab63fc7e0183e769dc7d4b752 100644
--- a/scripts/Interface/ui/sans_isis/sans_data_processor_gui.py
+++ b/scripts/Interface/ui/sans_isis/sans_data_processor_gui.py
@@ -1483,7 +1483,7 @@ class SANSDataProcessorGui(QtGui.QMainWindow, ui_sans_data_processor_window.Ui_S
                             self.menuEdit)
 
         # Actions that go in the 'File' menu
-        self._create_action(MantidQt.MantidWidgets.DataProcessorOpenTableCommand(self.data_processor_table),
+        self._create_action(MantidQt.MantidWidgets.OpenTableCommand(self.data_processor_table),
                             self.menuFile, workspace_list)
         self._create_action(MantidQt.MantidWidgets.NewTableCommand(self.data_processor_table),
                             self.menuFile)
@@ -1501,7 +1501,7 @@ class SANSDataProcessorGui(QtGui.QMainWindow, ui_sans_data_processor_window.Ui_S
     def _create_action(self, command, menu, workspace_list=None):
         """
         Create an action from a given DataProcessorCommand and add it to a given menu
         A 'workspace_list' can be provided but it is only intended to be used with DataProcessorOpenTableCommand.
         It refers to the list of table workspaces in the ADS that could be loaded into the widget. Note that only
         table workspaces with an appropriate number of columns and column types can be loaded.
         """
@@ -1501,7 +1501,7 @@ class SANSDataProcessorGui(QtGui.QMainWindow, ui_sans_data_processor_window.Ui_S
         """
         Create an action from a given DataProcessorCommand and add it to a given menu
-        A 'workspace_list' can be provided but it is only intended to be used with DataProcessorOpenTableCommand.
+        A 'workspace_list' can be provided but it is only intended to be used with OpenTableCommand.
         It refers to the list of table workspaces in the ADS that could be loaded into the widget. Note that only
         table workspaces with an appropriate number of columns and column types can be loaded.